==> accountbook-3.0b1.tar.gz: accountbook-3.0b1/public/cash.rb <==
#!/home/netsphere/bin/ruby
# -*- coding:utf-8 -*-

# Q's Account Book
# Copyright (c) 2002-2007 HORIKAWA Hisashi. All rights reserved.
#   mailto:vzw00011@nifty.ne.jp
#   http://www.nslabs.jp/

# 現金出納帳

require "pcview.rb"
require "journal-common.rb"

class CashbookPage < Wafu::Action
  def execute(af)
    day = Time.now
    day = Date.new(day.year, day.mon, day.day) - 1 if day.hour < 3
    
    period = UserSetting.get_addable_period(@app.user)

    # 表示
    lines = 12 # magic
    model = {
      :period => "#{period[0]} 〜 #{period[1]}",
      :mcode => get_sel_active_items(@app.user, "mcode", nil) {|item| item.cf_type == 4},
      :list => [],
      :lines => lines,
      :notice => @app.get_flash("notice")
    }
    (1..lines).each {|i|
      h = {
        :mon => "mon#{i}",
        :day => "day#{i}",
        :day_sel => "openCalendar(null, this.form.mon#{i}, this.form.day#{i}, event, 'mm/dd');",
        :accode => (i == 1 ? get_sel_active_items(@app.user, "accode-#{i}", nil) :
                    get_sel_active_items_with_zero(@app.user, "accode-#{i}", nil)),
        :drid => "dr#{i}",
        :crid => "cr#{i}",
        :remarks => "remarks-#{i}",
        :comment => "comment-#{i}"
      }
      if i == 1
        h[:monv] = day.mon
        h[:dayv] = day.day
      else
        h[:cont] = {:cont => "cont-#{i}"}
      end
      model[:list] << h
    }
    @app.page_out("cash.html", model)
  end
end

class CB_AF < Journal_CommonAF
  def validate()
    error = []
    result = []
    
    period = UserSetting.get_addable_period(@app.user)

    lines = @app.cgi["lines"].first.to_i
    mcode = @app.cgi["mcode"].first.to_i
    count = 0
    (1..lines).each {|i|
      r = []
      r[1] = @app.cgi["mon#{i}"].first.to_i
      r[2] = @app.cgi["day#{i}"].first.to_i
      if @app.cgi["dr#{i}"].first.to_i != 0
        r[3] = mcode                                 # drcode
        r[4] = @app.cgi["accode-#{i}"].first.to_i    # crcode
        r[5] = @app.cgi["dr#{i}"].first.to_i
      else
        r[3] = @app.cgi["accode-#{i}"].first.to_i
        r[4] = mcode
        r[5] = @app.cgi["cr#{i}"].first.to_i
      end
      r[6] = @app.cgi["remarks-#{i}"].first.strip
      r[7] = @app.cgi["comment-#{i}"].first.strip
      r[8] = @app.cgi["cont-#{i}"].first ? "on" : nil
      
      if r[5] != 0
        count += 1
        check_and_update(r, error, result, period)
        result << r
      end
    }
    error << "1件もデータがありません。" if count == 0

    @journal_data = result
    return set_error(error)
  end
  attr_reader :journal_data
end

class CashConfirmPage < ConfirmAction
  def execute(af)
    @action_url = "cash.rb"
    return execute_sub(af)
  end
end

class Form < PCView
  def main()
    actions = {
      "*" => [nil, CashbookPage, nil],
      "confirm" => [CB_AF, CashConfirmPage, CashConfirmPage],
      "determine" => [JournalActionForm, DetermineAction, CashConfirmPage]
    }
    dispatch(actions)
  end
end

if __FILE__ == $0
  run(Form.new)
end

==> accountbook-3.0.0.tar.gz: accountbook-3.0.0/public/cash.rb <==
#!/home/netsphere/bin/ruby
# -*- coding:utf-8 -*-

# Q's Web Account Book
# Copyright (c) 2002-2007,2010 HORIKAWA Hisashi. All rights reserved.
#   http://www.nslabs.jp/

# PC用　現金出納帳 


require "pcview.rb"
require "journal-common.rb"

class CashbookPage < Wafu::Action
  def execute(af)
    day = Time.now
    day = Date.new(day.year, day.mon, day.day) - 1 if day.hour < 3
    
    period = app.user.user_setting.get_addable_period

    # 表示
    lines = 12 # magic
    model = {
      :period => "#{period[0]} 〜 #{period[1]}",
      :mcode => get_sel_active_items(@app.user, "mcode", nil) {|item| item.cf_type == 4},
      :list => [],
      :lines => lines,
      :notice => @app.get_flash("notice")
    }
    (1..lines).each {|i|
      h = {
        :mon => "mon#{i}",
        :day => "day#{i}",
        :day_sel => "openCalendar(null, this.form.mon#{i}, this.form.day#{i}, event, 'mm/dd');",
        :accode => (i == 1 ? get_sel_active_items(@app.user, "accode-#{i}", nil) :
                    get_sel_active_items_with_zero(@app.user, "accode-#{i}", nil)),
        :drid => "dr#{i}",
        :crid => "cr#{i}",
        :remarks => "remarks-#{i}",
        :comment => "comment-#{i}"
      }
      if i == 1
        h[:monv] = day.mon
        h[:dayv] = day.day
      else
        h[:cont] = {:cont => "cont-#{i}"}
      end
      model[:list] << h
    }
    @app.page_out("cash.html", model)
  end
end

class CB_AF < Journal_CommonAF
  attr_reader :journal_data
  attr_reader :period

  def validate()
    error = []
    result = []
    
    @period = app.user.user_setting.get_addable_period

    lines = @app.cgi["lines"].first.to_i
    mcode = @app.cgi["mcode"].first.to_i
    count = 0
    (1..lines).each {|i|
      r = []
      r[1] = @app.cgi["mon#{i}"].first.to_i
      r[2] = @app.cgi["day#{i}"].first.to_i
      if @app.cgi["dr#{i}"].first.to_i != 0
        r[3] = mcode                                 # drcode
        r[4] = @app.cgi["accode-#{i}"].first.to_i    # crcode
        r[5] = @app.cgi["dr#{i}"].first.to_i
      else
        r[3] = @app.cgi["accode-#{i}"].first.to_i
        r[4] = mcode
        r[5] = @app.cgi["cr#{i}"].first.to_i
      end
      r[6] = @app.cgi["remarks-#{i}"].first.strip
      r[7] = @app.cgi["comment-#{i}"].first.strip
      r[8] = @app.cgi["cont-#{i}"].first ? "on" : nil
      
      if r[5] != 0
        count += 1
        check_and_update(r, error, result, @period)
        result << r
      end
    }
    error << "1件もデータがありません。" if count == 0

    @journal_data = result
    return set_error(error)
  end
end

class CashConfirmPage < ConfirmAction
  def execute(af)
    @action_url = "cash.rb"
    return execute_sub(af)
  end
end


if __FILE__ == $0
  PCView.new('actions' => {
      "*" => [nil, CashbookPage, nil],
      "confirm" => [CB_AF, CashConfirmPage, CashConfirmPage],
      "determine" => [JournalActionForm, DetermineAction, CashConfirmPage]
  }).run
end
